"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.viewRequiresUpdate = exports.tableRequiresUpdate = void 0;
const partitioning_1 = require("./partitioning");
async function tableRequiresUpdate({ table, config, documentIdColExists, pathParamsColExists, oldDataColExists, }) {
    /* Setup checks */
    const { metadata } = table;
    /** Check clustering */
    const configCluster = JSON.stringify(config.clustering);
    const tableCluster = JSON.stringify(metadata.clustering?.fields || []);
    if (configCluster !== tableCluster)
        return true;
    /** Check wildcards */
    if (!!config.wildcardIds !== pathParamsColExists)
        return true;
    /** Check document id column */
    if (!documentIdColExists)
        return true;
    /** Check old_data column exists */
    if (!oldDataColExists)
        return true;
    /** Check partitioning */
    const partitioning = new partitioning_1.Partitioning(config, table);
    const isValidPartition = await partitioning.isValidPartitionForExistingTable();
    if (isValidPartition)
        return true;
    // No updates have occured.
    return false;
}
exports.tableRequiresUpdate = tableRequiresUpdate;
function viewRequiresUpdate({ metadata, config, documentIdColExists, pathParamsColExists, oldDataColExists, }) {
    /** Check wildcards */
    if (!!config.wildcardIds !== pathParamsColExists)
        return true;
    /** Check document id column */
    if (!documentIdColExists)
        return true;
    /** Check old_data column exists */
    if (!oldDataColExists)
        return true;
    /* Using the new query syntax for snapshots */
    if (metadata) {
        const query = metadata.view?.query || "";
        const hasLegacyQuery = query.includes("FIRST_VALUE");
        const { useNewSnapshotQuerySyntax } = config;
        /** If enabled and has legacy query, can update */
        if (useNewSnapshotQuerySyntax && hasLegacyQuery)
            return true;
        /** If not enabled and has an updated query, can update */
        if (!useNewSnapshotQuerySyntax && !hasLegacyQuery)
            return true;
    }
    // No updates have occured.
    return false;
}
exports.viewRequiresUpdate = viewRequiresUpdate;
