"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Clustering = void 0;
const logs = require("../logs");
const VALID_CLUSTERING_TYPES = [
    "BIGNUMERIC",
    "BOOL",
    "DATE",
    "DATETIME",
    "GEOGRAPHY",
    "INT64",
    "NUMERIC",
    "RANGE",
    "STRING",
    "TIMESTAMP",
];
class Clustering {
    constructor(config, table, schema) {
        this.updateCluster = async (metaData) => {
            const clustering = { fields: this.config.clustering };
            metaData.clustering = clustering;
            logs.updatedClustering(this.config.clustering.join(","));
            return Promise.resolve();
        };
        this.removeCluster = async (metaData) => {
            metaData.clustering = null;
            logs.removedClustering(this.table.id);
            return Promise.resolve();
        };
        this.updateClustering = async (metaData) => {
            /** Return if invalid config */
            if (await this.hasInvalidFields(metaData))
                return Promise.resolve();
            return !!this.config.clustering && !!this.config.clustering.length
                ? this.updateCluster(metaData)
                : this.removeCluster(metaData);
        };
        this.config = config;
        this.table = table;
        this.schema = schema;
    }
    hasValidTableReference() {
        logs.invalidTableReference();
        return !!this.table;
    }
    async hasInvalidFields(metaData) {
        const { clustering = [] } = this.config;
        if (!clustering) {
            return false;
        }
        if (!clustering.length) {
            return false;
        }
        if (!metaData?.schema.fields.length) {
            return false;
        }
        const fields = metaData.schema.fields;
        const fieldNameToType = new Map(fields.map((field) => [field.name, field.type]));
        // First check if all clustering fields exist in the schema
        const nonExistentFields = clustering.filter((fieldName) => !fieldNameToType.has(fieldName));
        if (nonExistentFields.length) {
            logs.invalidClustering(nonExistentFields.join(","));
            return true;
        }
        // Then check for invalid types among existing clustering fields
        const invalidFieldTypes = clustering
            .map((fieldName) => ({
            fieldName,
            type: fieldNameToType.get(fieldName),
        }))
            .filter(({ type }) => !VALID_CLUSTERING_TYPES.includes(type));
        if (invalidFieldTypes.length) {
            logs.invalidClusteringTypes(invalidFieldTypes
                .map(({ fieldName, type }) => `${fieldName} (${type})`)
                .join(", "));
            return true;
        }
        return false;
    }
}
exports.Clustering = Clustering;
