import { Dataset, Table } from "@google-cloud/bigquery";
interface WaitForInitializationParams {
    dataset: Dataset;
    changelogName: string;
    materializedViewName?: string;
}
/**
 * Periodically checks for the existence of a dataset and table until both are found or a maximum number of attempts is reached.
 * @param {WaitForInitializationParams} params - Parameters for initialization including the dataset and the table name to check.
 * @param {number} maxAttempts - Maximum number of attempts before giving up (defaults to 12).
 * @returns {Promise<Table>} A promise that resolves with the Table if it exists, or rejects if it doesn't exist after maxAttempts or an error occurs.
 * @throws {Error} Throws an error if the dataset or table cannot be verified to exist after multiple attempts or if an unexpected error occurs.
 */
export declare function waitForInitialization({ dataset, changelogName, materializedViewName }: WaitForInitializationParams, maxAttempts?: number): Promise<Table>;
export declare function parseErrorMessage(error: unknown, process?: string): string;
export {};
